@@ -5,6 +5,7 @@ from gzip import GzipFile
 from cStringIO import StringIO
 from datetime import datetime, timedelta
 import logging
+import math
 
 import msgpack
 from tornado.concurrent import return_future
@@ -618,16 +619,24 @@ class SyncCache(object):
     def release_update_pages_lock(self, lock):
         return lock.release()
 
-    def fill_job_bucket(self, expiration, look_ahead_pages=1000):
+    def fill_job_bucket(self, expiration, look_ahead_pages=1000, avg_links_per_page=10.0):
         with Lock('next-job-fill-bucket-lock', redis=self.redis):
             expired_time = datetime.utcnow() - timedelta(seconds=expiration)
 
             active_domains = Domain.get_active_domains(self.db)
             active_domains_ids = [item.id for item in active_domains]
 
+            capacity = Limiter.get_limit_capacity(self.db, active_domains)
+            get_percentage = lambda domain_id: \
+                    capacity.get(domain_id, None) and \
+                    math.ceil(float(capacity[domain_id]) / avg_links_per_page) or \
+                    look_ahead_pages
+
             all_domains_pages_in_need_of_review = []
 
             for domain_id in active_domains_ids:
+                pages_to_get = get_percentage(domain_id)
+
                 pages = self.db \
                     .query(
                         Page.uuid,
@@ -640,7 +649,7 @@ class SyncCache(object):
                         Page.last_review_date == None,
                         Page.last_review_date <= expired_time
                     )) \
-                    .order_by(Page.last_review_date.asc())[:look_ahead_pages]
+                    .order_by(Page.last_review_date.asc())[:pages_to_get]
 
                 if pages:
                     all_domains_pages_in_need_of_review.append(pages)
